#!/bin/bash

MACHINES=/home/anna/Machines

if [ ! -f DataONTAP.vmdk ]; then
	echo "Must be run in a vsim directory"
	exit 1
fi


echo -n "What should the vsim be named? DataONTAP_"
read RELEASE
ONTAP=DataONTAP_$RELEASE


echo "DataONTAP.vmdk ==> $ONTAP.qcow2"
qemu-img convert -p -O qcow2 DataONTAP.vmdk $ONTAP.qcow2

echo "DataONTAP-var.vmdk ==> $ONTAP-var.qcow2"
qemu-img convert -p -O qcow2 DataONTAP-var.vmdk $ONTAP-var.qcow2

echo "DataONTAP-nvram.vmdk ==> $ONTAP-nvram.qcow2"
qemu-img convert -p -O qcow2 DataONTAP-nvram.vmdk $ONTAP-nvram.qcow2

echo "DataONTAP-sim.vmdk ==> $ONTAP-sim.qcow2"
qemu-img convert -p -O qcow2 DataONTAP-sim.vmdk $ONTAP-sim.qcow2

mv *.qcow2 $MACHINES


DESC=`grep "Created" DataONTAP.vmx | awk -F'# ' '{print $2}'`
MEMORY=`grep memsize DataONTAP.vmx | awk -F\" '{print $2}'`
CPUS=`grep numvcpus DataONTAP.vmx | awk -F\" '{print $2}'`

virt-install --connect qemu:///system \
	--name $ONTAP \
	--description "$DESC" \
	--os-variant=freebsd12.1 \
	--ram=$MEMORY \
	--vcpus=$CPUS \
	--check all=off \
	--disk path=$MACHINES/$ONTAP.qcow2,bus=ide \
	--disk path=$MACHINES/$ONTAP-var.qcow2,bus=ide \
	--disk path=$MACHINES/$ONTAP-nvram.qcow2,bus=ide \
	--disk path=$MACHINES/$ONTAP-sim.qcow2,bus=ide \
	--network network="default",model=e1000 \
	--network network="default",model=e1000 \
	--network network="default",model=e1000 \
	--network network="default",model=e1000 \
	--import
